@@ -1,4 +1,4 @@
-def wavytdw(url, output):
+def wav_ytdw(url, output):
     
     from youtube_dl import YoutubeDL
     from os import remove
